==> lxqt-config_0.14.1.orig.tar.xz: lxqt-config-0.14.1/lxqt-config-file-associations/translations/lxqt-config-file-associations_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>Selector de aplicativos</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>Escolla un aplicativo para:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>Aplicativos para manexar JPEG</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>Novo subelemento</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="113"/>
        <source>Other applications</source>
        <translation>Outros aplicativos</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="114"/>
        <source>Applications that handle %1</source>
        <translation>Aplicativos para manexar %1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="151"/>
        <source>No applications found</source>
        <translation>Non se atoparon aplicativos</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="156"/>
        <location filename="../mimetypeviewer.cpp" line="207"/>
        <source>None</source>
        <translation>Ningún</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="203"/>
        <source>&amp;Change...</source>
        <translation>&amp;Cambiar...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="208"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Escoller...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>Asociacións de ficheiros</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="56"/>
        <source>Default application</source>
        <translation>Aplicativo predeterminado</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="68"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Escoller...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="117"/>
        <source>TextLabel</source>
        <translation>EtiquetaDeTexto</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="124"/>
        <source>None</source>
        <translation>Ningunha</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="144"/>
        <source>Patterns</source>
        <translation>Modelos</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="156"/>
        <source>*.txt *.xml</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="173"/>
        <source>MIME type</source>
        <translation>Tipo MIME</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="191"/>
        <source>Icon</source>
        <translation>Icona</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="198"/>
        <source>Description</source>
        <translation>Descrición</translation>
    </message>
</context>
</TS>

==> lxqt-config_0.15.0.orig.tar.xz: lxqt-config-0.15.0/lxqt-config-file-associations/translations/lxqt-config-file-associations_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>Selector de aplicacións</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>Escolla unha aplicación para:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>Aplicacións para manexar JPEG</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>Novo subelemento</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="113"/>
        <source>Other applications</source>
        <translation>Outras aplicacións</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="114"/>
        <source>Applications that handle %1</source>
        <translation>Aplicacións para manexar %1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="151"/>
        <source>No applications found</source>
        <translation>Non se atoparon aplicacións</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="156"/>
        <location filename="../mimetypeviewer.cpp" line="207"/>
        <source>None</source>
        <translation>Ningún</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="203"/>
        <source>&amp;Change...</source>
        <translation>&amp;Cambiar...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="208"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Escoller...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>Asociacións de ficheiros</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="56"/>
        <source>Default application</source>
        <translation>Aplicación predeterminada</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="68"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Escoller...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="117"/>
        <source>TextLabel</source>
        <translation>EtiquetaDeTexto</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="124"/>
        <source>None</source>
        <translation>Ningunha</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="144"/>
        <source>Patterns</source>
        <translation>Modelos</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="156"/>
        <source>*.txt *.xml</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="173"/>
        <source>MIME type</source>
        <translation>Tipo MIME</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="191"/>
        <source>Icon</source>
        <translation>Icona</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="198"/>
        <source>Description</source>
        <translation>Descrición</translation>
    </message>
</context>
</TS>
